/**
 * File:
 *  7SegLED.c
 *
 * Notes:
 *  This file contains the implementation of the 7 segment LED display routines.
 *
 * Functions:
 *  get7SegLEDmask     Returns the bit mask for a specific alpha-numeric char.
 *  initSevenSegLEDs   Initialises the 7 segment LED's
 *
 *
 * History:
 *  07/05/2012 Created by Simon Platten
 *  13/05/2012 Added createSchedule
 *  14/05/2012 Modified createSchedule to use a static array for the schedule
 *             Limitation, you can have only one schedule!
 */
#include "7SegLED.h"

static volatile unsigned char aryuc7Seg[NUM_OF_7SEG_LEDS];

/**
 * Function:
 *  initSevenSegLEDs
 *
 * Parameters:
 *  none
 *
 * Returns:
 *  none
 */
void initSevenSegLEDs(void) {
}
/**
 * Function:
 *  update7SegLEDs
 *
 * Parameters:
 *  ulngCtr, the value to show
 *  ulngFreq, the value in Hz of the update counter
 *
 * Returns:
 *  none
 */
void update7SegLEDs(unsigned long ulngCtr, unsigned long ulngFreq) {
  static unsigned short us7SegIdx = 0;
  static unsigned short usShifter = 1;
  static int intLast = -1;
// Service 7 segment LED's
  LATA = 0;                           // Turn off all 7seg displays
  LATD = aryuc7Seg[us7SegIdx];        // bring appropriate value to PORTD
  LATA = usShifter;                   // turn on appropriate 7seg. display
// Increment portd_index
  if ( ++us7SegIdx >= NUM_OF_7SEG_LEDS ) {
    us7SegIdx = 0;              // turn on 1st, turn off 2nd 7seg.
  }
// Move shifter to next digit
  usShifter <<= 1;
  if ( usShifter > 8 ) {
    usShifter = 1;
  }
// Get the number of seconds elasped
  //if ( (ulngCtr % ulngFreq) == 0 )
  {
    int intNum;
    intNum = (int)(ulngCtr / ulngFreq);
    aryuc7Seg[3] = get7SegLEDmask((unsigned char)('0' + (intNum / 1000)));
    aryuc7Seg[2] = get7SegLEDmask((unsigned char)('0' + ((intNum / 100) % 10)));
    aryuc7Seg[1] = get7SegLEDmask((unsigned char)('0' + ((intNum / 10) % 10)));
    aryuc7Seg[0] = get7SegLEDmask((unsigned char)('0' + (intNum % 10)));
  }
}