/**
 * File:
 *  7SegLED.h
 *
 * Notes:
 *  This file contains the macro sevenSegLED which can be used to obtain the
 * correct bit mask for writing to a seven segment LED.
 *
 * Hex
 * 01 = TOP
 * 02 = TOP-RIGHT
 * 04 = BOTTOM-RIGHT
 * 08 = BOTTOM
 * 10 = BOTTOM-LEFT
 * 20 = TOP-LEFT
 * 40 = MIDDLE
 * 80 = DP
 *
 * History:
 *  18/03/2012 Created by Simon Platten
 */
#ifndef SSLED_H
  #define SSLED_H
  #include "fader.h"
// Constants
  #define NUM_OF_7SEG_LEDS      4
// Macros
/**
 * Macro:
 *  get7SegLEDmask
 *
 * Parameters:
 *  bChar, the alpha-numeric ASCII byte value to translate
 *
 * Returns:
 *  The bit mask that represents the passed byte, 0 if bChar is invalid
 */
 #define get7SegLEDmask(ucChar) \
          (((ucChar) == '0') ? 0x3F : \
            ((ucChar) == '1') ? 0x06 : \
              ((ucChar) == '2') ? 0x5B : \
                ((ucChar) == '3') ? 0x4F : \
                  ((ucChar) == '4') ? 0x66 : \
                    ((ucChar) == '5') ? 0x6D : \
                      ((ucChar) == '6') ? 0x7D : \
                        ((ucChar) == '7') ? 0x07 : \
                          ((ucChar) == '8') ? 0x7F : \
                            ((ucChar) == '9') ? 0x6F : \
                              ((ucChar) == 'A') ? 0x77 : \
                                ((ucChar) == 'B') ? 0x7C : \
                                  ((ucChar) == 'C') ? 0x39 : \
                                    ((ucChar) == 'D') ? 0x5E : \
                                      ((ucChar) == 'E') ? 0x79 : \
                                        ((ucChar) == 'F') ? 0x71 : (ucChar));
// Prototypes
   void update7SegLEDs(unsigned long ulngCtr, unsigned long ulngFreq);
#endif