/**
 * File:
 *  KnightRider.c
 *
 * Notes:
 *  Simple demo created for the easyPic7 board.
 *
 * Ports B, C & D:
 *      SW3: 2, 3 and 4 ON
 *
 * Turn on LCD backlight:
 *      SW4: 6 On
 *
 * History:
 *  29/04/2012 Written by Simon Platten
 *  02/06/2012 Moved animation to just ports C and D
 */
#include "anim.h"
#include "7SegLED.h"
#include "lcd.h"
// Constants
#define TIMER_FREQUENCY         ((uint)5000) // Hz
#define DELAY_BETWEEN_LEDS      (TIMER_FREQUENCY / 25)

static volatile outputScheduleDef aryLEDseqC[] = {
  { 0, 0, DELAY_BETWEEN_LEDS },
  { 1, 0, DELAY_BETWEEN_LEDS },
  { 2, 0, DELAY_BETWEEN_LEDS },
  { 3, 0, DELAY_BETWEEN_LEDS },
  { 4, 0, DELAY_BETWEEN_LEDS },
  { 5, 0, DELAY_BETWEEN_LEDS },
  { 6, 0, DELAY_BETWEEN_LEDS },
  { 7, 0, DELAY_BETWEEN_LEDS } };
static volatile outputScheduleDef aryLEDseqD[] = {
  { 0, 0, DELAY_BETWEEN_LEDS },
  { 1, 0, DELAY_BETWEEN_LEDS },
  { 2, 0, DELAY_BETWEEN_LEDS },
  { 3, 0, DELAY_BETWEEN_LEDS },
  { 4, 0, DELAY_BETWEEN_LEDS },
  { 5, 0, DELAY_BETWEEN_LEDS },
  { 6, 0, DELAY_BETWEEN_LEDS },
  { 7, 0, DELAY_BETWEEN_LEDS } };
static volatile animDef animC =
  { &LATC, (sizeof(aryLEDseqC) / sizeof(aryLEDseqC[0])), 3, aryLEDseqC };
static volatile animDef animD =
  { &LATD, (sizeof(aryLEDseqD) / sizeof(aryLEDseqD[0])), 3, aryLEDseqD };
// Counter to show on 7 Segment LED's
//static volatile ulong ulngCtr;
/**
 * Interrupt handler
 */
void interrupt() {
  playAnimation(&animC);
//  update7SegLEDs(ulngCtr, TIMER_FREQUENCY);
/*
  if ( (LATE & 0x1) == 0x01 ) {
    LATD = LATE;
  }
*/
/*
  ulngCtr++;
  
  if ( ulngCtr >= 15000 ) {
    ulngCtr = 0;
  }
*/
  TMR0H = 0xF9;    // preset for Timer0 MSB register
  TMR0L = 0xC0;    // preset for Timer0 LSB register
  TMR0IF_bit = 0;
}
/**
 * Entry point
 */
void main() {
  int intSteps;
// Set-up hardware
#ifdef P18F45K22
//  ANSELA = 0;                    // Configure PORTA pins as digital
  ANSELB = 0;                    // Configure PORTB pins as digital
  ANSELC = 0;                    // Configure PORTC pins as digital
  ANSELD = 0;                    // Configure PORTD pins as digital
  ANSELE = 0;                    // Configure PORTE pins as digital
#endif
#ifdef P18F4550
  ADCON1 = 0x0f;                 // Configure all ports as digital
#endif
//  TRISA = 0;                     // Configure PORTA as output
//  TRISB = 0;                     // Configure PORTB as output
  TRISC = 0;                     // Configure PORTC as output
  TRISD = 0;                     // Configure PORTD as output
  TRISE = 1;                     // Configure PORTE as input
//  LATA = 0;                      // Clear PORTA
//  LATB = 0;                      // Clear PORTB
  LATC = 0;                      // Clear PORTC
  LATD = 0;                      // Clear PORTD
// Initialise the LCD display
  initLCD();
// Display the application title
  lcdText(1, -1, "KnightRider v1");
// Initialise counter
//  ulngCtr = 0;
// Create fader schedule
  intSteps = createSchedule(5, 0);
// Create and initilise the faders
  initAnim(&animC, intSteps);
  initAnim(&animD, intSteps);
// Join animation sequences to form one sequence
  joinAnims(&animC, &animD);
// Timer0 Registers:
// 16-Bit Mode; Prescaler=1:1;
  T0CON.TMR0ON = 1;// On/Off Control bit, 1=Enable, 0=Disable
  T0CON.T08BIT = 0;// 8-bit/16-bit Control bi: 0=16-bit timer/counter
  T0CON.T0CS   = 0;// Clock Source Select bit: 0=Internal Clock (CLKO)
  T0CON.T0SE   = 0;// Source Edge Select bit: 0=low/high
  T0CON.PSA    = 1;// Prescaler Assignment bit: 1=NOT assigned/bypassed
  T0CON.T0PS2  = 0;// bits 2-0  PS2:PS0: Prescaler Select bits
  T0CON.T0PS1  = 0;
  T0CON.T0PS0  = 0;
// TMRH Preset=F9; TMRL Preset=C0; Freq=5,000.00Hz; Period=200,000 ns
  TMR0H = 0xF9;    // preset for Timer0 MSB register
  TMR0L = 0xC0;    // preset for Timer0 LSB register
  TMR0IE_bit = 1;
// Global interrupt enable
  GIE_bit = 1;

  while( 1 ) {
// Loop forever
  }
}